# TestCaseBulkCfMoveStrategy


## Enum

* `ADD` (value: `'ADD'`)

* `MAP` (value: `'MAP'`)

* `EXCLUDE` (value: `'EXCLUDE'`)

* `REWRITE` (value: `'REWRITE'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


